"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("../../lib/color");
const errors_1 = require("../../lib/errors");
const core_1 = require("./core");
class ConfigureCommand extends core_1.DeployConfCommand {
    async getMetadata() {
        return {
            name: 'configure',
            type: 'project',
            groups: ["hidden" /* HIDDEN */],
            summary: 'Overrides Appflow Deploy configuration',
            description: `
This command overrides configuration for the Appflow Deploy plugin (${color_1.input('cordova-plugin-ionic')}) in Capacitor projects.

For Capacitor projects, if the plugin is already installed, it overrides the configuration variables in the native projects.

For Cordova projects this is not implemented because it is better to reinstall the plugin with the different parameters and let Cordova deal with the changes.
      `,
            exampleCommands: [
                '',
                '--app-id="abcd1234" --channel-name="Master" --update-method="background"',
                '--max-store=2 --min-background-duration=30',
                '--app-id="abcd1234" --channel-name="Master" --update-method="background" --max-store=2 --min-background-duration=30',
            ],
            options: this.commandOptions,
        };
    }
    async preRun(inputs, options) {
        // check if it is already installed
        const alreadyAdded = await this.checkDeployInstalled();
        if (!alreadyAdded) {
            throw new errors_1.FatalException(`Deploy (cordova-plugin-ionic) not yet installed.\n` +
                `Please run ${color_1.input('ionic deploy add')}`);
        }
        // check if there are native integration installed
        await this.requireNativeIntegration();
        await this.preRunCheckInputs(options);
    }
    async run(inputs, options, runinfo) {
        const integration = await this.getAppIntegration();
        if (integration === 'cordova') {
            throw new errors_1.FatalException(`Deploy (cordova-plugin-ionic) configuration cannot be overridden for a Cordova project.\n` +
                `Please uninstall the plugin and run ${color_1.input('ionic deploy add')} again.`);
        }
        if (integration === 'capacitor') {
            // update the ios project if present
            await this.addConfToIosPlist(options);
            // update the android project if present
            await this.addConfToAndroidString(options);
            this.env.log.ok(`Deploy (cordova-plugin-ionic) configs successfully overridden for the project\n`);
        }
    }
}
exports.ConfigureCommand = ConfigureCommand;
